@@ -10,7 +10,7 @@ class DftbplusStep(object):
     description of this node, and create_node() and create_tk_node() methods
     for creating the graphical and non-graphical nodes.
 
-    Attributes
+    Parameters
     ----------
     my_description : {}
         A human-readable description of this step. It can be
