@@ -272,10 +272,108 @@ class EnergyParameters(seamm.Parameters):
         },
     }
 
+    output = {
+        "total density": {
+            "default": "yes",
+            "kind": "boolean",
+            "default_units": "",
+            "enumeration": ("yes", "no"),
+            "format_string": "",
+            "description": "Plot total density:",
+            "help_text": "Whether to plot the total charge density.",
+        },
+        "total spin density": {
+            "default": "yes",
+            "kind": "boolean",
+            "default_units": "",
+            "enumeration": ("yes", "no"),
+            "format_string": "",
+            "description": "Plot total spin density:",
+            "help_text": "Whether to plot the total spin density.",
+        },
+        "difference density": {
+            "default": "yes",
+            "kind": "boolean",
+            "default_units": "",
+            "enumeration": ("yes", "no"),
+            "format_string": "",
+            "description": "Plot difference density:",
+            "help_text": "Whether to plot the difference density.",
+        },
+        "orbitals": {
+            "default": "yes",
+            "kind": "boolean",
+            "default_units": "",
+            "enumeration": ("yes", "no"),
+            "format_string": "",
+            "description": "Plot orbitals:",
+            "help_text": "Whether to plot orbitals.",
+        },
+        "selected orbitals": {
+            "default": "-1, HOMO, LUMO, +1",
+            "kind": "string",
+            "default_units": "",
+            "enumeration": ("all", "-1, HOMO, LUMO, +1"),
+            "format_string": "",
+            "description": "Selected orbitals:",
+            "help_text": "Which orbitals to plot.",
+        },
+        "selected k-points": {
+            "default": "none",
+            "kind": "string",
+            "default_units": "",
+            "enumeration": ("none", "all"),
+            "format_string": "",
+            "description": "For crystals, k-points:",
+            "help_text": "Plots the orbitals at these k-points.",
+        },
+        "region": {
+            "default": "default",
+            "kind": "string",
+            "default_units": "",
+            "enumeration": ("default", "explicit"),
+            "format_string": "",
+            "description": "Region:",
+            "help_text": "The region for the plots",
+        },
+        "nx": {
+            "default": 50,
+            "kind": "integer",
+            "default_units": "",
+            "enumeration": None,
+            "format_string": "",
+            "description": "Grid:",
+            "help_text": "Number of grid points in first direction",
+        },
+        "ny": {
+            "default": 50,
+            "kind": "integer",
+            "default_units": "",
+            "enumeration": None,
+            "format_string": "",
+            "description": "x",
+            "help_text": "Number of grid points in second direction",
+        },
+        "nz": {
+            "default": 50,
+            "kind": "integer",
+            "default_units": "",
+            "enumeration": None,
+            "format_string": "",
+            "description": "x",
+            "help_text": "Number of grid points in first direction",
+        },
+    }
+
     def __init__(self, defaults={}, data=None):
         """Initialize the instance, by default from the default
         parameters given in the class"""
 
         super().__init__(
-            defaults={**EnergyParameters.parameters, **defaults}, data=data
+            defaults={
+                **EnergyParameters.parameters,
+                **EnergyParameters.output,
+                **defaults,
+            },
+            data=data,
         )
